@@ -10,7 +10,7 @@
 
 #include "abstractfile/indexercommon.h"
 
-#if KF5FileMetaData_FOUND
+#if KFFileMetaData_FOUND
 
 #include <KFileMetaData/ExtractorCollection>
 #include <KFileMetaData/Extractor>
@@ -18,7 +18,7 @@
 #include <KFileMetaData/UserMetaData>
 #include <KFileMetaData/Properties>
 
-#if KF5Baloo_FOUND
+#if KFBaloo_FOUND
 
 #include <Baloo/File>
 
@@ -32,24 +32,31 @@
 #include <QHash>
 #include <QMimeDatabase>
 
+QStringList buildCoverFileNames(const QStringList &fileNames, const QStringList &fileExtensions)
+{
+    QStringList covers {};
+    for (const auto &fileName : fileNames) {
+        for (const auto &fileExtension : fileExtensions) {
+            covers.push_back(fileName + fileExtension);
+        }
+    }
+    return covers;
+}
+
 class FileScannerPrivate
 {
 public:
-#if KF5FileMetaData_FOUND
+#if KFFileMetaData_FOUND
     KFileMetaData::ExtractorCollection mAllExtractors;
 
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
     KFileMetaData::PropertyMultiMap mAllProperties;
-#else
-    KFileMetaData::PropertyMap mAllProperties;
-#endif
 
     KFileMetaData::EmbeddedImageData mImageScanner;
 #endif
 
     QMimeDatabase mMimeDb;
 
-#if KF5FileMetaData_FOUND
+#if KFFileMetaData_FOUND
     const QHash<KFileMetaData::Property::Property, DataTypes::ColumnsRoles> propertyTranslation = {
         {KFileMetaData::Property::Artist, DataTypes::ColumnsRoles::ArtistRole},
         {KFileMetaData::Property::AlbumArtist, DataTypes::ColumnsRoles::AlbumArtistRole},
@@ -71,20 +78,29 @@ public:
     };
 #endif
 
-    const QStringList constSearchStrings = {
-        QStringLiteral("*[Cc]over*.jpg")
-        ,QStringLiteral("*[Cc]over*.jpeg")
-        ,QStringLiteral("*[Cc]over*.png")
-        ,QStringLiteral("*[Ff]older*.jpg")
-        ,QStringLiteral("*[Ff]older*.jpeg")
-        ,QStringLiteral("*[Ff]older*.png")
-        ,QStringLiteral("*[Ff]ront*.jpg")
-        ,QStringLiteral("*[Ff]ront*.jpeg")
-        ,QStringLiteral("*[Ff]ront*.png")
-        ,QStringLiteral("*[Aa]lbumart*.jpg")
-        ,QStringLiteral("*[Aa]lbumart*.jpeg")
-        ,QStringLiteral("*[Aa]lbumart*.png")
+    const QStringList constCoverExtensions {
+        QStringLiteral(".jpg")
+        ,QStringLiteral(".jpeg")
+        ,QStringLiteral(".png")
     };
+
+    const QStringList constCoverNames {
+        QStringLiteral("[Cc]over")
+        ,QStringLiteral("[Cc]over[Ii]mage")
+        ,QStringLiteral("[Ff]older")
+        ,QStringLiteral("[Aa]lbumart")
+    };
+
+    const QStringList constCoverGlobs = {
+        QStringLiteral("*[Cc]over*")
+        ,QStringLiteral("*[Ff]older*")
+        ,QStringLiteral("*[Ff]ront*")
+        ,QStringLiteral("*[Aa]lbumart*")
+    };
+
+    const QStringList coverFileAllImages = buildCoverFileNames({QStringLiteral("*")}, constCoverExtensions);
+    const QStringList coverFileNames = buildCoverFileNames(constCoverNames, constCoverExtensions);
+    const QStringList coverFileGlobs = buildCoverFileNames(constCoverGlobs, constCoverExtensions);
 };
 
 FileScanner::FileScanner() : d(std::make_unique<FileScannerPrivate>())
@@ -114,7 +130,7 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile, const QF
     newTrack[DataTypes::RatingRole] = 0;
     newTrack[DataTypes::ElementTypeRole] = ElisaUtils::Track;
 
-#if KF5FileMetaData_FOUND
+#if KFFileMetaData_FOUND
     const auto &fileMimeType = d->mMimeDb.mimeTypeForFile(localFileName);
     if (!fileMimeType.name().startsWith(QLatin1String("audio/"))) {
         return newTrack;
@@ -173,7 +189,7 @@ DataTypes::TrackDataType FileScanner::scanOneFile(const QUrl &scanFile)
 DataTypes::TrackDataType FileScanner::scanOneBalooFile(const QUrl &scanFile, const QFileInfo &scanFileInfo)
 {
     DataTypes::TrackDataType newTrack;
-#if KF5Baloo_FOUND
+#if KFBaloo_FOUND
     const auto &localFileName = scanFile.toLocalFile();
 
     newTrack[DataTypes::FileModificationTime] = scanFileInfo.metadataChangeTime();
@@ -200,7 +216,7 @@ DataTypes::TrackDataType FileScanner::scanOneBalooFile(const QUrl &scanFile, con
 
 void FileScanner::scanProperties(const QString &localFileName, DataTypes::TrackDataType &trackData)
 {
-#if KF5FileMetaData_FOUND
+#if KFFileMetaData_FOUND
     if (d->mAllProperties.isEmpty()) {
         return;
     }
@@ -275,20 +291,37 @@ QUrl FileScanner::searchForCoverFile(const QString &localFileName)
     }
 
     trackFileDir.setFilter(QDir::Files);
-    trackFileDir.setNameFilters(d->constSearchStrings);
+    trackFileDir.setNameFilters(d->coverFileAllImages);
     QFileInfoList coverFiles = trackFileDir.entryInfoList();
+
+    if (coverFiles.isEmpty()) {
+        directoryCache.insert(trackFileDir.path(), QUrl());
+        return QUrl();
+    }
+
+    if (coverFiles.length() != 1) {
+        trackFileDir.setNameFilters(d->coverFileNames);
+        coverFiles = trackFileDir.entryInfoList();
+    }
+
+    if (coverFiles.isEmpty()) {
+        trackFileDir.setNameFilters(d->coverFileGlobs);
+        coverFiles = trackFileDir.entryInfoList();
+    }
+
     if (coverFiles.isEmpty()) {
         const QString dirNamePattern = QLatin1String("*") + trackFileDir.dirName() + QLatin1String("*");
         const QString dirNameNoSpaces = QLatin1String("*") + trackFileDir.dirName().remove(QLatin1Char(' ')) + QLatin1String("*");
-        const QStringList filters = {
-            dirNamePattern + QStringLiteral(".jpg"),
-            dirNamePattern + QStringLiteral(".png"),
-            dirNameNoSpaces + QStringLiteral(".jpg"),
-            dirNameNoSpaces + QStringLiteral(".png")
-        };
+        auto filters = buildCoverFileNames({dirNamePattern, dirNameNoSpaces}, d->constCoverExtensions);
         trackFileDir.setNameFilters(filters);
         coverFiles = trackFileDir.entryInfoList();
     }
+
+    if (coverFiles.isEmpty()) {
+        trackFileDir.setNameFilters(d->coverFileAllImages);
+        coverFiles = trackFileDir.entryInfoList();
+    }
+
     if (coverFiles.isEmpty()) {
         directoryCache.insert(trackFileDir.path(), QUrl());
         return QUrl();
@@ -302,7 +335,7 @@ QUrl FileScanner::searchForCoverFile(const QString &localFileName)
 
 bool FileScanner::checkEmbeddedCoverImage(const QString &localFileName)
 {
-#if KF5FileMetaData_FOUND
+#if KFFileMetaData_FOUND
     const auto &mimeType = QMimeDatabase().mimeTypeForFile(localFileName).name();
     auto extractors = d->mAllExtractors.fetchExtractors(mimeType);
 
