@@ -76,6 +76,7 @@ void ElisaConfigurationDialog::save()
     Elisa::ElisaConfiguration::setShowProgressOnTaskBar(mShowProgressInTaskBar);
     Elisa::ElisaConfiguration::setShowSystemTrayIcon(mShowSystemTrayIcon);
     Elisa::ElisaConfiguration::setForceUsageOfFastFileSearch(!mForceUsageOfSlowFileSystemIndexing);
+    Elisa::ElisaConfiguration::setAlwaysUseAbsolutePlaylistPaths(mAlwaysUseAbsolutePlaylistPaths);
     Elisa::ElisaConfiguration::setPlayAtStartup(mPlayAtStartup);
     Elisa::ElisaConfiguration::setScanAtStartup(mScanAtStartup);
     Elisa::ElisaConfiguration::setColorScheme(mColorScheme);
@@ -102,10 +103,12 @@ void ElisaConfigurationDialog::save()
     case ElisaUtils::FileName:
     case ElisaUtils::Lyricist:
     case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 
     Elisa::ElisaConfiguration::setInitialView(mInitialViewIndex);
+    Elisa::ElisaConfiguration::setInitialFilesViewPath(mInitialFilesViewPath);
 
     Elisa::ElisaConfiguration::self()->save();
 
@@ -171,6 +174,18 @@ void ElisaConfigurationDialog::setForceUsageOfSlowFileSystemIndexing(bool forceU
     setDirty();
 }
 
+void ElisaConfigurationDialog::setAlwaysUseAbsolutePlaylistPaths(bool alwaysUseAbsolutePlaylistPaths)
+{
+    if (mAlwaysUseAbsolutePlaylistPaths == alwaysUseAbsolutePlaylistPaths) {
+        return;
+    }
+
+    mAlwaysUseAbsolutePlaylistPaths = alwaysUseAbsolutePlaylistPaths;
+    Q_EMIT alwaysUseAbsolutePlaylistPathsChanged();
+
+    setDirty();
+}
+
 void ElisaConfigurationDialog::setEmbeddedView(ElisaUtils::PlayListEntryType embeddedView)
 {
     if (mEmbeddedView == embeddedView) {
@@ -195,6 +210,18 @@ void ElisaConfigurationDialog::setInitialViewIndex(int initialViewIndex)
     setDirty();
 }
 
+void ElisaConfigurationDialog::setInitialFilesViewPath(const QString &path)
+{
+    if (mInitialFilesViewPath == path) {
+        return;
+    }
+
+    mInitialFilesViewPath = path;
+    Q_EMIT initialFilesViewPathChanged();
+
+    setDirty();
+}
+
 void ElisaConfigurationDialog::setPlayAtStartup(bool playAtStartup)
 {
     if (mPlayAtStartup == playAtStartup) {
@@ -274,6 +301,9 @@ void ElisaConfigurationDialog::configChanged()
     mForceUsageOfSlowFileSystemIndexing = !Elisa::ElisaConfiguration::forceUsageOfFastFileSearch();
     Q_EMIT forceUsageOfSlowFileSystemIndexingChanged();
 
+    mAlwaysUseAbsolutePlaylistPaths = Elisa::ElisaConfiguration::alwaysUseAbsolutePlaylistPaths();
+    Q_EMIT alwaysUseAbsolutePlaylistPathsChanged();
+
     switch (Elisa::ElisaConfiguration::embeddedView())
     {
     case Elisa::ElisaConfiguration::EnumEmbeddedView::NoView:
@@ -293,6 +323,9 @@ void ElisaConfigurationDialog::configChanged()
 
     mInitialViewIndex = Elisa::ElisaConfiguration::initialView();
     Q_EMIT initialViewIndexChanged();
+
+    mInitialFilesViewPath = Elisa::ElisaConfiguration::initialFilesViewPath();
+    Q_EMIT initialFilesViewPathChanged();
 }
 
 void ElisaConfigurationDialog::setDirty()
