@@ -19,7 +19,7 @@
 
 #include <KAboutData>
 
-#if KF5Crash_FOUND
+#if KFCrash_FOUND
 #include <KCrash>
 #endif
 
@@ -71,10 +71,6 @@ int main(int argc, char *argv[])
     qInfo() << "Application starting...";
 
     qputenv("QT_LOGGING_RULES", "org.kde.elisa*=true");
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
 #endif
     qputenv("QT_GSTREAMER_USE_PLAYBIN_VOLUME", "true");
 
@@ -84,7 +80,7 @@ int main(int argc, char *argv[])
     QApplication::setStyle(QStringLiteral("breeze"));
 #endif
 
-    KLocalizedString::setApplicationDomain("elisa");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("elisa"));
 
 #if QtAndroidExtras_FOUND
     qInfo() << QCoreApplication::arguments();
@@ -95,7 +91,7 @@ int main(int argc, char *argv[])
                                               QtAndroid::androidContext().object());
 #endif
 
-#if KF5Crash_FOUND
+#if KFCrash_FOUND
     KCrash::initialize();
 #endif
 
