@@ -38,6 +38,11 @@ class ELISALIB_EXPORT ViewManager : public QObject
                WRITE setInitialIndex
                NOTIFY initialIndexChanged)
 
+    Q_PROPERTY(QString initialFilesViewPath
+               READ initialFilesViewPath
+               WRITE setInitialFilesViewPath
+               NOTIFY initialFilesViewPathChanged)
+
     Q_PROPERTY(ViewsListData* viewsData READ viewsData WRITE setViewsData NOTIFY viewsDataChanged)
 
 public:
@@ -94,13 +99,6 @@ public:
 
     Q_ENUM(ModelType)
 
-    enum IsTreeModelType {
-        IsTreeModel = true,
-        IsFlatModel = false,
-    };
-
-    Q_ENUM(IsTreeModelType)
-
     explicit ViewManager(QObject *parent = nullptr);
 
     ~ViewManager() override;
@@ -109,6 +107,8 @@ public:
 
     [[nodiscard]] int initialIndex() const;
 
+    [[nodiscard]] QString initialFilesViewPath() const;
+
     [[nodiscard]] ViewsListData* viewsData() const;
 
 Q_SIGNALS:
@@ -127,6 +127,8 @@ Q_SIGNALS:
 
     void viewsDataChanged();
 
+    void initialFilesViewPathChanged();
+
 public Q_SLOTS:
 
     void openView(int viewIndex);
@@ -139,8 +141,6 @@ public Q_SLOTS:
 
     void openNowPlaying();
 
-    void viewIsLoaded();
-
     void goBack();
 
     void setViewsData(ViewsListData* viewsData);
@@ -151,6 +151,8 @@ public Q_SLOTS:
 
     void setInitialIndex(int newIndex);
 
+    void setInitialFilesViewPath(const QString &initialPath);
+
 private Q_SLOTS:
 
     void openInitialView();
@@ -166,14 +168,17 @@ private:
 
     QStringList::iterator findViewPreference(QStringList &list, const QString &viewId) const;
 
-    [[nodiscard]] Qt::SortOrder computePreferredSortOrder(Qt::SortOrder initialValue) const;
+    bool viewHasDefaultSortRole(const ElisaUtils::FilterType filterType) const;
 
-    [[nodiscard]] int computePreferredSortRole(int initialValue) const;
+    [[nodiscard]] Qt::SortOrder computePreferredSortOrder(Qt::SortOrder initialValue, ElisaUtils::FilterType filterType) const;
+
+    [[nodiscard]] int computePreferredSortRole(int initialValue, ElisaUtils::FilterType filterType) const;
 
 private:
 
     std::unique_ptr<ViewManagerPrivate> d;
 
+    bool isSameView(const ViewParameters &currentView, const ViewParameters &otherView) const;
 };
 
 #endif // VIEWMANAGER_H
